@@ -1,11 +1,10 @@
 package Role::Declare;
 use strict;
 use warnings;
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 use Attribute::Handlers;
 use Carp qw[ croak ];
-use Data::Alias;
 use Function::Parameters;
 use Import::Into;
 use Role::Tiny;
@@ -25,10 +24,10 @@ use constant {    # Attribute::Handlers argument positions
 my %return_hooks;
 
 sub _install_hook {
-    my ( $type, $target, $hook ) = @_;
-    alias my $hook_slot = $return_hooks{ refaddr($target) }{$type};
-    croak "A $type hook for $target already exists" if defined $hook_slot;
-    $hook_slot = $hook;
+    my ($type, $target, $hook) = @_;
+    my $hooks = $return_hooks{ refaddr($target) } //= {};
+    croak "A $type hook for $target already exists" if defined $hooks->{$type};
+    $hooks->{$type} = $hook;
     return;
 }
 
